==> stacked_services-0.5.4.tar.gz: example/lib/ui/views/snackbar_view.dart <==
import 'package:example/app/locator.dart';
import 'package:example/enums/snackbar_type.dart';
import 'package:flutter/material.dart';
import 'package:stacked_services/stacked_services.dart';

class SnackbarView extends StatelessWidget {
  SnackbarView({Key key}) : super(key: key);

  final _snackbarService = locator<SnackbarService>();

  @override
  Widget build(BuildContext context) {
    return Center(
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: <Widget>[
          Text(
            'Press the button below to show a regular snackbar',
            softWrap: true,
            style: TextStyle(
              fontSize: 14,
            ),
          ),
          OutlineButton(
            onPressed: () async {
              _snackbarService.showSnackbar(
                message: 'This is a snack bar',
                title: 'The title',
                duration: Duration(seconds: 2),
                onTap: (_) {
                  print('snackbar tapped');
                },
                mainButtonTitle: 'Undo',
                onMainButtonTapped: () => print('Undo the action!'),
              );
            },
            child: Text(
              'Show Snackbar',
            ),
          ),
          Text(
            'Press the button below to show blueAndYellow snackbar',
            softWrap: true,
            style: TextStyle(
              fontSize: 14,
            ),
          ),
          OutlineButton(
            onPressed: () async {
              _snackbarService.showCustomSnackBar(
                customData: SnackbarType.blueAndYellow,
                message: 'Blue and yellow',
                title: 'The message is the message',
                duration: Duration(seconds: 2),
                onTap: (_) {
                  print('snackbar tapped');
                },
                mainButtonTitle: 'Undo',
                onMainButtonTapped: () => print('Undo the action!'),
              );
            },
            child: Text(
              'Show Blue and Yellow Snackbar',
            ),
          ),
          Text(
            'Press the button below to show a regular snackbar',
            softWrap: true,
            style: TextStyle(
              fontSize: 14,
            ),
          ),
          OutlineButton(
            onPressed: () async {
              _snackbarService.showCustomSnackBar(
                customData: SnackbarType.greenAndRed,
                title: 'Green and Red',
                message:
                    'The text is green and red and the background is white',
                duration: Duration(seconds: 2),
                onTap: (_) {
                  print('snackbar tapped');
                },
                mainButtonTitle: 'Undo',
                onMainButtonTapped: () => print('Undo the action!'),
              );
            },
            child: Text(
              'Show Green and Red Snackbar',
            ),
          ),
        ],
      ),
    );
  }
}

==> stacked_services-0.8.1.tar.gz: example/lib/ui/views/snackbar_view.dart <==
import 'package:example/app/locator.dart';
import 'package:example/enums/snackbar_type.dart';
import 'package:flutter/material.dart';
import 'package:stacked_services/stacked_services.dart';

class SnackbarView extends StatelessWidget {
  SnackbarView({Key key}) : super(key: key);

  final _snackbarService = locator<SnackbarService>();

  @override
  Widget build(BuildContext context) {
    return Center(
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: <Widget>[
          Text(
            'Press the button below to show a regular snackbar',
            softWrap: true,
            style: TextStyle(
              fontSize: 14,
            ),
          ),
          OutlineButton(
            onPressed: () async {
              _snackbarService.showSnackbar(
                message: 'This is a snack bar',
                title: 'The title',
                duration: Duration(seconds: 2),
                onTap: (_) {
                  print('snackbar tapped');
                },
                mainButtonTitle: 'Undo',
                onMainButtonTapped: () => print('Undo the action!'),
              );
            },
            child: Text(
              'Show Snackbar',
            ),
          ),
          Text(
            'Press the button below to show blueAndYellow snackbar',
            softWrap: true,
            style: TextStyle(
              fontSize: 14,
            ),
          ),
          OutlineButton(
            onPressed: () async {
              _snackbarService.showCustomSnackBar(
                variant: SnackbarType.blueAndYellow,
                message: 'Blue and yellow',
                title: 'The message is the message',
                duration: Duration(seconds: 2),
                onTap: (_) {
                  print('snackbar tapped');
                },
                mainButtonTitle: 'Undo',
                onMainButtonTapped: () => print('Undo the action!'),
              );
            },
            child: Text(
              'Show Blue and Yellow Snackbar',
            ),
          ),
          Text(
            'Press the button below to show a regular snackbar',
            softWrap: true,
            style: TextStyle(
              fontSize: 14,
            ),
          ),
          OutlineButton(
            onPressed: () async {
              _snackbarService.showCustomSnackBar(
                variant: SnackbarType.greenAndRed,
                message:
                    'The text is green and red and the background is white',
                duration: Duration(seconds: 2),
                onTap: (_) {
                  print('snackbar tapped');
                },
                mainButtonTitle: 'Undo',
                onMainButtonTapped: () => print('Undo the action!'),
              );
            },
            child: Text(
              'Show Green and Red Snackbar',
            ),
          ),
        ],
      ),
    );
  }
}
